@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc
  * File       : showinfo.c
- * Version    : $Id: showinfo.c,v 1.18 2005/09/15 12:14:00 peter Exp $
- * Copyright  : 2001-2004 by Peter Bieringer <pb (at) bieringer.de>
+ * Version    : $Id: showinfo.c,v 1.20 2005/10/21 13:42:33 peter Exp $
+ * Copyright  : 2001-2005 by Peter Bieringer <pb (at) bieringer.de>
  * 
  * Information:
  *  Function to show information about a given IPv6 address
@@ -40,10 +40,10 @@ void showinfo_availabletypes(void) {
 	fprintf(stderr, " IPV6=...                      : given IPv6 address full uncompressed\n");
 	fprintf(stderr, " IPV6_REGISTRY=...             : registry token of given IPv6 address\n");
 	fprintf(stderr, " IPV6_PREFIXLENGTH=ddd         : given prefix length\n");
-	fprintf(stderr, " IPV4_6TO4=ddd.ddd.ddd.ddd     : 6to4 IPv4 address\n");
-	fprintf(stderr, " IPV4_6TO4_REGISTRY=...        : registry token of 6to4 IPv4 address\n");
-	fprintf(stderr, " IPV4=ddd.ddd.ddd.ddd          : an included IPv4 address in IID\n");
+	fprintf(stderr, " IPV4=ddd.ddd.ddd.ddd          : an included IPv4 address in IID (e.g. ISATAP, TEREDO)\n");
 	fprintf(stderr, " IPV4_REGISTRY=...             : registry token of IPv4 address in IID\n");
+	fprintf(stderr, " IPV4_SOURCE=...               : source of IPv4 address\n");
+	fprintf(stderr, "  ISATAP|TEREDO|6TO4|LINK-LOCAL-IID\n");
 	fprintf(stderr, " IPV4_PREFIXLENGTH=...         : given prefix length of IPv4 address\n");
 	fprintf(stderr, " SLA=xxxx                      : an included SLA\n");
 	fprintf(stderr, " IID=xxxx:xxxx:xxxx:xxxx       : an included interface identifier\n");
@@ -54,6 +54,9 @@ void showinfo_availabletypes(void) {
 	fprintf(stderr, " EUI64=xx:xx:xx:xx:xx:xx:xx:xx : an included EUI-64 identifier\n");
 	fprintf(stderr, " EUI64_SCOPE=local|global      : scope of EUI-64 identifier\n");
 	fprintf(stderr, " OUI=\"...\"                     : OUI string, if available\n");
+	fprintf(stderr, " TEREDO_IPV4_SERVER=...        : IPv4 address of Teredo server\n");
+	fprintf(stderr, " TEREDO_PORT_CLIENT=...        : port of Teredo client (NAT outside)\n");
+	fprintf(stderr, " TEREDO_IPV4_SERVER_REGISTRY=..: registry token of IPv4 address of Teredo server\n");
 	fprintf(stderr, " IPV6CALC_VERSION=x.y          : Version of ipv6calc\n");
 	fprintf(stderr, " IPV6CALC_COPYRIGHT=\"...\"      : Copyright string\n");
 };
@@ -288,9 +291,10 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 	int retval = 1, i, j, flag_prefixuse, registry;
 	char tempstring[NI_MAXHOST] = "", helpstring[NI_MAXHOST] = "";
 	ipv6calc_ipv6addr ipv6addr, *ipv6addrp;
-	ipv6calc_ipv4addr ipv4addr;
+	ipv6calc_ipv4addr ipv4addr, ipv4addr2;
 	ipv6calc_macaddr macaddr;
 	ipv6calc_eui64addr eui64addr;
+	uint16_t port;
 	uint32_t typeinfo;
 	uint32_t machinereadable = ( formatoptions & FORMATOPTION_machinereadable);
 
@@ -373,7 +377,8 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 		};	
 
 		if ( machinereadable != 0 ) {
-			snprintf(tempstring, sizeof(tempstring) - 1, "IPV4_6TO4=%s", helpstring);
+			printout("IPV4_SOURCE=6TO4");
+			snprintf(tempstring, sizeof(tempstring) - 1, "IPV4=%s", helpstring);
 			printout(tempstring);
 		} else {
 			fprintf(stdout, "Address type is 6to4 and included IPv4 address is: %s\n", helpstring);
@@ -381,22 +386,62 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 
 		/* get registry string */
 		retval = libipv4addr_get_registry_string(&ipv4addr, helpstring);
-		if ( retval != 0 ) {
-			fprintf(stderr, "Error getting registry string for IPv4 address: %s\n", helpstring);
-			retval = 1;
-			goto END;
-		};
-		
 		if ( machinereadable != 0 ) {
-			snprintf(tempstring, sizeof(tempstring) - 1, "IPV4_6TO4_REGISTRY=%s", helpstring);
+			snprintf(tempstring, sizeof(tempstring) - 1, "IPV4_REGISTRY=%s", helpstring);
 			printout(tempstring);
 		} else {
 			fprintf(stderr, "IPv4 registry for 6to4 address: %s\n", helpstring);
 		};
 	};
 
+	if ( (typeinfo & IPV6_NEW_ADDR_TEREDO) != 0 ) {
+		/* extract Teredo client IPv4 address */
+		for (i = 0; i <= 3; i++) {
+			ipv4addr_setoctett(&ipv4addr, (unsigned int) i, (unsigned int) ipv6addr_getoctett(ipv6addrp, (unsigned int) 12 + i) ^ 0xff);
+		};
+
+		/* extract Teredo server IPv4 address */
+		for (i = 0; i <= 3; i++) {
+			ipv4addr_setoctett(&ipv4addr2, (unsigned int) i, (unsigned int) ipv6addr_getoctett(ipv6addrp, (unsigned int) 4 + i));
+		};
+
+		if ( machinereadable != 0 ) {
+			printout("IPV4_SOURCE=ISATAP");
+		};
+		print_ipv4addr(&ipv4addr, formatoptions);
+
+		retval = libipv4addr_ipv4addrstruct_to_string(&ipv4addr, helpstring, 0);
+		if ( retval != 0 ) {
+			fprintf(stderr, "Error converting IPv4 address to string\n");
+			retval = 1;
+			goto END;
+		};	
+
+		/* extract Teredo client UDP port */
+		port = ((unsigned int) ipv6addr_getoctett(ipv6addrp, (unsigned int) 10) << 8 | (unsigned int) ipv6addr_getoctett(ipv6addrp, (unsigned int) 11)) ^ 0xffff;
+
+		if ( machinereadable != 0 ) {
+			snprintf(tempstring, sizeof(tempstring) - 1, "TEREDO_IPV4_SERVER=%s", helpstring);
+			printout(tempstring);
+			snprintf(tempstring, sizeof(tempstring) - 1, "TEREDO_PORT_CLIENT=%d", port);
+			printout(tempstring);
+		} else {
+			fprintf(stdout, "Address type is Teredo and included IPv4 server address is: %s and client port: %d\n", helpstring, port);
+		};
+
+		/* get registry string */
+		retval = libipv4addr_get_registry_string(&ipv4addr2, helpstring);
+		
+		if ( machinereadable != 0 ) {
+			snprintf(tempstring, sizeof(tempstring) - 1, "TEREDO_IPV4_SERVER_REGISTRY=%s", helpstring);
+			printout(tempstring);
+		} else {
+			fprintf(stderr, "IPv4 registry for Teredo server address: %s\n", helpstring);
+		};
+	};
+
 	/* SLA prefix included? */
-	if ( (typeinfo & ( IPV6_ADDR_SITELOCAL | IPV6_NEW_ADDR_AGU | IPV6_ADDR_ULUA ) ) != 0 ) {
+	if ( ((typeinfo & ( IPV6_ADDR_SITELOCAL | IPV6_NEW_ADDR_AGU | IPV6_ADDR_ULUA )) != 0) && ((typeinfo & (IPV6_NEW_ADDR_TEREDO)) == 0)) {
 		if ( machinereadable != 0 ) {
 			snprintf(tempstring, sizeof(tempstring) - 1, "SLA=%04x", (unsigned int) ipv6addr_getword(ipv6addrp, 3));
 			printout(tempstring);
@@ -453,7 +498,7 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 	};
 
 	/* Interface identifier included */
-	if ( ((typeinfo & (IPV6_ADDR_LINKLOCAL | IPV6_ADDR_SITELOCAL | IPV6_NEW_ADDR_AGU | IPV6_ADDR_ULUA )) != 0) || ((typeinfo & (IPV6_ADDR_LOOPBACK | IPV6_NEW_ADDR_SOLICITED_NODE)) == (IPV6_ADDR_LOOPBACK | IPV6_NEW_ADDR_SOLICITED_NODE)) ) {
+	if ( ( ((typeinfo & (IPV6_ADDR_LINKLOCAL | IPV6_ADDR_SITELOCAL | IPV6_NEW_ADDR_AGU | IPV6_ADDR_ULUA )) != 0) || ((typeinfo & (IPV6_ADDR_LOOPBACK | IPV6_NEW_ADDR_SOLICITED_NODE)) == (IPV6_ADDR_LOOPBACK | IPV6_NEW_ADDR_SOLICITED_NODE)) ) && ((typeinfo & (IPV6_NEW_ADDR_TEREDO)) == 0) ) {
 		if ( machinereadable != 0 ) {
 			snprintf(tempstring, sizeof(tempstring) - 1, "IID=%04x:%04x:%04x:%04x", (unsigned int) ipv6addr_getword(ipv6addrp, 4), (unsigned int) ipv6addr_getword(ipv6addrp, 5), (unsigned int) ipv6addr_getword(ipv6addrp, 6), (unsigned int) ipv6addr_getword(ipv6addrp, 7));
 			printout(tempstring);
@@ -490,7 +535,18 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 					} else {
 						fprintf(stdout, "Generated from the extension identifier of an EUI-48 (MAC): ...:%02x:%02x:%02x\n", (unsigned int) ipv6addr_getoctett(ipv6addrp, 13), (unsigned int) ipv6addr_getoctett(ipv6addrp, 14), (unsigned int) ipv6addr_getoctett(ipv6addrp, 15));
 					};
-				} else if ( ((typeinfo & IPV6_NEW_ADDR_ISATAP) != 0) || (((typeinfo & IPV6_ADDR_LINKLOCAL) != 0) && (ipv6addr_getdword(ipv6addrp, 2) == 0 && ipv6addr_getword(ipv6addrp, 6) != 0)) )   {
+				} else if ( (typeinfo & IPV6_NEW_ADDR_ISATAP) != 0 )  {
+					for (i = 0; i <= 3; i++) {
+						ipv4addr_setoctett(&ipv4addr, (unsigned int) i, (unsigned int) ipv6addr_getoctett(ipv6addrp, (unsigned int) (i + 12)));
+					};
+
+					if ( machinereadable != 0 ) {
+						printout("IPV4_SOURCE=ISATAP");
+					} else {
+						fprintf(stderr, "IPv4 registry for ISATAP client address: %s\n", helpstring);
+					};
+					print_ipv4addr(&ipv4addr, formatoptions);
+				} else if ( ( ( (typeinfo & IPV6_ADDR_LINKLOCAL) != 0) && (ipv6addr_getdword(ipv6addrp, 2) == 0 && ipv6addr_getword(ipv6addrp, 6) != 0)) )   {
 					/* fe80:: must have 0000:0000:xxxx:yyyy where xxxx > 0 */
 					if ( machinereadable != 0 ) {
 					} else {
@@ -499,6 +555,9 @@ int showinfo_ipv6addr(const ipv6calc_ipv6addr *ipv6addrp1, const uint32_t format
 					for (i = 0; i <= 3; i++) {
 						ipv4addr_setoctett(&ipv4addr, (unsigned int) i, (unsigned int) ipv6addr_getoctett(ipv6addrp, (unsigned int) (i + 12)));
 					};
+					if ( machinereadable != 0 ) {
+						printout("IPV4_SOURCE=LINK-LOCAL-IID");
+					};
 					print_ipv4addr(&ipv4addr, formatoptions);
 				} else {
 					if ( machinereadable != 0 ) {
