@@ -1,8 +1,8 @@
 /*
  * Project    : ipv6calc/lib
  * File       : libipv6addr.h
- * Version    : $Id: libipv6addr.h,v 1.17 2005/07/25 20:59:43 peter Exp $
- * Copyright  : 2001-2003 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
+ * Version    : $Id: libipv6addr.h,v 1.21 2005/10/26 09:36:54 peter Exp $
+ * Copyright  : 2001-2005 by Peter Bieringer <pb (at) bieringer.de> except the parts taken from kernel source
  *
  * Information:
  *  Header file for libipv6addr.c
@@ -32,8 +32,10 @@ typedef struct {
 
 /* IPv6 address assignment structure */
 typedef struct {
-	const uint32_t ipv6addr;
-	const uint32_t ipv6mask;
+	const uint32_t ipv6addr_00_31;
+	const uint32_t ipv6addr_32_63;
+	const uint32_t ipv6mask_00_31;
+	const uint32_t ipv6mask_32_63;
 	const char *string_registry;
 } s_ipv6addr_assignment;
 
@@ -80,6 +82,7 @@ typedef struct {
 #define IPV6_NEW_ADDR_ISATAP			(uint32_t) 0x00200000U
 #define IPV6_NEW_ADDR_PRODUCTIVE		(uint32_t) 0x00400000U
 #define IPV6_NEW_ADDR_6TO4_MICROSOFT		(uint32_t) 0x00800000U
+#define IPV6_NEW_ADDR_TEREDO			(uint32_t) 0x01000000U
 
 /* Registries */
 #define IPV6_ADDR_REGISTRY_6BONE	0x01
@@ -88,6 +91,7 @@ typedef struct {
 #define IPV6_ADDR_REGISTRY_ARIN		0x04
 #define IPV6_ADDR_REGISTRY_RIPE		0x05
 #define IPV6_ADDR_REGISTRY_LACNIC	0x06
+#define IPV6_ADDR_REGISTRY_AFRINIC	0x07
 #define IPV6_ADDR_REGISTRY_RESERVED	0x0e
 #define IPV6_ADDR_REGISTRY_UNKNOWN	0x0f
 
@@ -116,7 +120,8 @@ typedef struct {
 	{ IPV6_NEW_ADDR_SOLICITED_NODE	, "solicited-node" },
 	{ IPV6_NEW_ADDR_ISATAP		, "ISATAP" },
 	{ IPV6_NEW_ADDR_PRODUCTIVE	, "productive" },
-	{ IPV6_NEW_ADDR_6TO4_MICROSOFT	, "6to4-microsoft" }
+	{ IPV6_NEW_ADDR_6TO4_MICROSOFT	, "6to4-microsoft" },
+	{ IPV6_NEW_ADDR_TEREDO		, "TEREDO" }
 };
 
 typedef struct {
@@ -131,6 +136,8 @@ typedef struct {
 	{ IPV6_ADDR_REGISTRY_APNIC	, "APNIC"	, "APNIC" 	},
 	{ IPV6_ADDR_REGISTRY_ARIN	, "ARIN" 	, "ARIN"	},
 	{ IPV6_ADDR_REGISTRY_RIPE	, "RIPE NCC"	, "RIPENCC"	},
+	{ IPV6_ADDR_REGISTRY_LACNIC	, "LACNIC"	, "LACNIC"	},
+	{ IPV6_ADDR_REGISTRY_AFRINIC	, "AFRINIC"	, "AFRINIC"	},
 	{ IPV6_ADDR_REGISTRY_RESERVED	, "reserved"	, "reserved"	},
 	{ IPV6_ADDR_REGISTRY_UNKNOWN	, "unknown"	, "unknown"	}
 };
